#
# spec file for package python3-jupyter_client
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-jupyter_client
Version:        4.3.0
Release:        1.4
Summary:        Jupyter protocol implementation and client libraries
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://jupyter.org
Source:         https://files.pythonhosted.org/packages/source/j/jupyter_client/jupyter_client-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-jupyter_core
BuildRequires:  python3-pyzmq >= 13
BuildRequires:  python3-setuptools
BuildRequires:  python3-traitlets
# Test Requirements
BuildRequires:  python3-nose
BuildRequires:  python3-pytest
Requires:       python3-jupyter_core
Requires:       python3-pyzmq >= 13
Requires:       python3-traitlets
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildConflicts: python3-buildservice-tweak
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
This package contains the reference implementation of the Jupyter protocol.
It also provides client and kernel management APIs for working with kernels.

It also provides the jupyter kernelspec entrypoint for installing kernelspecs
for use with Jupyter frontends.

%prep
%setup -q -n jupyter_client-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

# Prepare for update-alternatives usage
mv %{buildroot}%{_bindir}/jupyter-kernelspec %{buildroot}%{_bindir}/jupyter3-kernelspec
ln -s -f %{_bindir}/jupyter3-kernelspec %{buildroot}%{_bindir}/jupyter-kernelspec-%{py3_ver} 

mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -s -f %{_sysconfdir}/alternatives/jupyter-kernelspec %{buildroot}%{_bindir}/jupyter-kernelspec
# create a dummy target for /etc/alternatives/jupyter-kernelspec
touch %{buildroot}%{_sysconfdir}/alternatives/jupyter-kernelspec

%check
# We can't test the kernel manager because that requires the ipython kernel,
# which requires this package, causing a dependency loop.  So those tests are
# excluded
pushd jupyter_client/tests
PYTHONPATH=%{buildroot}%{python3_sitelib} nosetests -I test_multikernelmanager.py  -I test_kernelmanager.py
popd

%post
%_sbindir/update-alternatives \
   --install %{_bindir}/jupyter-kernelspec jupyter-kernelspec %{_bindir}/jupyter-kernelspec-%{py3_ver} 30

%preun
if [ $1 -eq 0 ] ; then
    %_sbindir/update-alternatives --remove jupyter-kernelspec %{_bindir}/jupyter-kernelspec-%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc CONTRIBUTING.md COPYING.md README.md
%{_bindir}/jupyter-kernelspec
%{_bindir}/jupyter3-kernelspec
%{_bindir}/jupyter-kernelspec-%{py3_ver}
%ghost %{_sysconfdir}/alternatives/jupyter-kernelspec
%{python3_sitelib}/*

%changelog
* Wed Jul 27 2016 toddrme2178@gmail.com
- Update to version 4.3.0
  * Adds ``--sys-prefix`` argument to :command:`jupyter kernelspec install`,
    for better symmetry with :command:`jupyter nbextension install`, etc.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Sat Mar 12 2016 arun@gmx.de
- update to version 4.2.2:
  * Another fix for the :func:`start_new_kernel` issue in 4.2.1
    affecting slow-starting kernels.
* Mon Mar  7 2016 arun@gmx.de
- update to version 4.2.1:
  * Fix regression in 4.2 causing :func:`start_new_kernel` to fail
    while waiting for kernels to become available.
* Sat Mar  5 2016 arun@gmx.de
- update to version 4.2.0:
  * added :command:`jupyter kernelspec remove` for removing
    kernelspecs
  * allow specifying the environment for kernel processes via the env
    argument
  * added name field to connection files identifying the kernelspec
    name, so that consumers of connection files (alternate frontends)
    can identify the kernelspec in use
  * added :meth:`KernelSpecManager.get_all_specs` for getting all
    kernelspecs more efficiently
  * various improvements to error messages and documentation
* Wed Feb 17 2016 toddrme2178@gmail.com
- Split documentation to speed up building.
  This is a dependency of a lot of other packages, and the
  dependencies for the documentation are very heavy.  So build
  the documentation separately to avoid holding up the build
  process.
* Thu Jan  7 2016 toddrme2178@gmail.com
- Tests fail with python3-buildservice-tweak
* Sat Oct 10 2015 arun@gmx.de
- update to version 4.1.1:
  * Setuptools fixes for jupyter kernelspec
  * jupyter kernelspec list includes paths
  * add :meth:`KernelManager.blocking_client`
  * provisional implementation of comm_info requests from upcoming 5.1
    release of the protocol
* Thu Oct  1 2015 toddrme2178@gmail.com
- Fix documentation location.
* Thu Oct  1 2015 toddrme2178@gmail.com
- Build documentation
* Fri Aug 14 2015 toddrme2178@gmail.com
- Fix update-alternatives usage
* Tue Jul 21 2015 toddrme2178@gmail.com
- Initial version
